==> commons-iterators-1.1.5-sources.jar: net/markenwerk/commons/iterators/ShortArrayIterator.java <==
/*
 * Copyright (c) 2015 Torsten Krause, Markenwerk GmbH
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.markenwerk.commons.iterators;

import java.util.Iterator;

/**
 * A {@link ShortArrayIterator} is an {@link Iterator} that iterates over a
 * given {@code short[]}.
 * 
 * <p>
 * Calling {@link ShortArrayIterator#remove()} sets the array to {@literal 0} at
 * the index that corresponds to the last value returned by
 * {@link ShortArrayIterator#next()}.
 * 
 * @author Torsten Krause (tk at markenwerk dot net)
 * @since 1.0.0
 */
public final class ShortArrayIterator implements Iterator<Short> {

	private final short[] values;

	private final Short replacement;

	private int index = -1;

	/**
	 * Creates a new {@linkplain ShortArrayIterator} that iterates over the
	 * given {@code short[]}.
	 * 
	 * <p>
	 * If the given {@code short[]} is {@literal null}, the new
	 * {@link ShortArrayIterator} will behave, as if an empty {@code short[]}
	 * has been given.
	 * 
	 * @param values
	 *            The {@code short[]} to iterate over.
	 */
	public ShortArrayIterator(short[] values) {
		this(values, null);
	}

	/**
	 * Creates a new {@linkplain ShortArrayIterator} that iterates over the
	 * given {@code short[]}.
	 * 
	 * <p>
	 * If the given {@code short[]} is {@literal null}, the new
	 * {@link ShortArrayIterator} will behave, as if an empty {@code short[]}
	 * has been given.
	 * 
	 * @param values
	 *            The {@code short[]} to iterate over.
	 * @param replacement
	 *            The value to replace removed values with.
	 */
	public ShortArrayIterator(short[] values, short replacement) {
		this(values, Short.valueOf(replacement));
	}

	private ShortArrayIterator(short[] values, Short replacement) {
		this.values = null == values ? new short[0] : values;
		this.replacement = replacement;
	}

	public boolean hasNext() {
		return values.length != index + 1;
	}

	public Short next() {
		index++;
		return values[index];
	}

	public void remove() {
		if (null != replacement) {
			values[index] = replacement;
		} else {
			throw new UnsupportedOperationException("Cannot remove from an array.");
		}
	}

}

==> commons-iterators-2.0.0-sources.jar: net/markenwerk/commons/iterators/ShortArrayIterator.java <==
/*
 * Copyright (c) 2015 Torsten Krause, Markenwerk GmbH
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.markenwerk.commons.iterators;

import java.util.Iterator;

/**
 * A {@link ShortArrayIterator} is an {@link Iterator} that iterates over a
 * given {@code short[]}.
 * 
 * <p>
 * Calling {@link ShortArrayIterator#remove()} sets the array to {@literal 0} at
 * the index that corresponds to the last value returned by
 * {@link ShortArrayIterator#next()}.
 * 
 * @author Torsten Krause (tk at markenwerk dot net)
 * @since 1.0.0
 */
public final class ShortArrayIterator implements Iterator<Short> {

	private final short[] array;

	private final Short replacement;

	private int index = -1;

	/**
	 * Creates a new {@linkplain ShortArrayIterator} that iterates over the
	 * given {@code short[]}.
	 * 
	 * <p>
	 * If the given {@code short[]} is {@literal null}, the new
	 * {@link ShortArrayIterator} will behave, as if an empty {@code short[]}
	 * has been given.
	 * 
	 * @param array
	 *            The {@code short[]} to iterate over.
	 * 
	 * @throws IllegalArgumentException
	 *             If the given {@code short[]} is {@literal null}.
	 */
	public ShortArrayIterator(short[] array) throws IllegalArgumentException {
		this(array, null);
	}

	/**
	 * Creates a new {@linkplain ShortArrayIterator} that iterates over the
	 * given {@code short[]}.
	 * 
	 * <p>
	 * If the given {@code short[]} is {@literal null}, the new
	 * {@link ShortArrayIterator} will behave, as if an empty {@code short[]}
	 * has been given.
	 * 
	 * @param array
	 *            The {@code short[]} to iterate over.
	 * @param replacement
	 *            The value to replace removed values with.
	 * 
	 * @throws IllegalArgumentException
	 *             If the given {@code short[]} is {@literal null}.
	 */
	public ShortArrayIterator(short[] array, short replacement) throws IllegalArgumentException {
		this(array, Short.valueOf(replacement));
	}

	private ShortArrayIterator(short[] array, Short replacement) throws IllegalArgumentException {
		if (null == array) {
			throw new IllegalArgumentException("array is null");
		}
		this.array = array;
		this.replacement = replacement;
	}

	public boolean hasNext() {
		return array.length != index + 1;
	}

	public Short next() {
		index++;
		return array[index];
	}

	public void remove() {
		if (null != replacement) {
			array[index] = replacement;
		} else {
			throw new UnsupportedOperationException("Cannot remove from an array.");
		}
	}

}
